==> cms-db_v0.7.5.tar.gz: blog.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

chdir('./admin');
$locale = new LocalizingClass('blog', $locale_default);
chdir('../');

/* Prevent displaying files outside of the blog directory */
if (strpos($query_string_data, '..') === false) {
	$template->addToHead('<link rel="alternate" type="application/atom+xml" title="'.locale('desc_feed-common',true).'" href="'.$urlabsolute.'/blogfeed.php?l='.$locale_default.'&amp;p='.$query_string[0].'" />');

	$query_string_data = explode('/', $query_string_data);

	$action = $query_string_data[0];
	$argument = $query_string_data[1];

	$blogurl = $current_page;
	$blog = '';

	if (in_array('useh1', $blogattr)) {
		$opentitletag = '<h1 class="blogtitle">';
		$closetitletag = '</h1>';
	} elseif (in_array('useh2', $blogattr)) {
		$opentitletag = '<h2 class="blogtitle">';
		$closetitletag = '</h2>';
	} elseif (in_array('useh3', $blogattr)) {
		$opentitletag = '<h3 class="blogtitle">';
		$closetitletag = '</h3>';
	} elseif (in_array('useh4', $blogattr)) {
		$opentitletag = '<h4 class="blogtitle">';
		$closetitletag = '</h4>';
	} elseif (in_array('useh5', $blogattr)) {
		$opentitletag = '<h5 class="blogtitle">';
		$closetitletag = '</h5>';
	} elseif (in_array('useh6', $blogattr)) {
		$opentitletag = '<h6 class="blogtitle">';
		$closetitletag = '</h6>';
	} else {
		$opentitletag = '<div class="blogtitle">';
		$closetitletag = '</div>';
	}

	function displayArticle($article, $link = true) {
		global $blogurl, $urlbefore, $urlafter, $blog, $blogattr, $opentitletag, $closetitletag;
		if (file_exists('./data/blog/articles/'.$article.'/content')) {
			$blog .= '<div class="blogarticle">';
			$data = file_get_contents('./data/blog/articles/'.$article.'/content');
			$data = explode("\n", $data, 5);
			$title = $data[0];
			$data[1] = explode('-', $data[1], 2);
			$user = $data[1][0];
			$author = $data[1][1];
			if (file_exists('./data/users/'.$user)) {
				include('./data/users/'.$user);
				$author = $user;
			}
			$time = $data[2];
			$tags = $data[3];
			$text = $data[4];
			$blog.= '<div class="blogheader">';
			if ($link == true && !in_array('nolinks', $blogattr)) {
				$blog.= $opentitletag.'<a href="'.$urlbefore.$blogurl.'/articles/'.$article.$urlafter.'">'.htmlspecialchars($title).'</a>'.$closetitletag;
			} else {
				$blog.= $opentitletag.htmlspecialchars($title).$closetitletag;
			}
			$blog.= '<div class="blogmeta">'.sprintf(locale('desc_meta',true), $author, date('d.m.Y', $time), date('H:i:s', $time)).'</div>';
			$blog.= '</div>';
			$blog.= '<div class="blogcontent">'.$text.'</div>';
			$tags = explode(' ', $tags);
			$blog.= '<div class="blogfooter">'.locale('desc_tags',true).' ';
			foreach ($tags as $tag) {
				$blog.= '<a href="'.$urlbefore.$blogurl.'/tags/'.$tag.$urlafter.'">'.$tag.'</a> ';
			}
			if ($link == true) {
				if (file_exists('./data/blog/articles/'.$article.'/comments')) {
					$count = count(file('./data/blog/articles/'.$article.'/comments'));
					if ($count == 0) {
						$linktext = locale('link_no-comments',true);
					} elseif ($count == 1) {
						$linktext = locale('link_one-comment',true);
					} else {
						$linktext = $count.' '.locale('link_comments',true);
					}
				} else {
					$linktext = locale('link_no-comments',true);
				}
				$blog.= '- <a href="'.$urlbefore.$blogurl.'/articles/'.$article.$urlafter.'">'.$linktext.'</a></div>';
			} else {
				$blog.= '</div>';
			}
			$blog .= '</div>';
		} else {
			$blog.= '<p>ERROR: The article doesn\'t exist.</p>';
		}
	}
	function getPaginationPage($p, $page, $a) {
		global $blogurl, $urlbefore, $urlafter;
		if ($page != $p) {
			return '<a href="'.$urlbefore.$blogurl.$a.$p.$urlafter.'">'.$p.'</a> ';
		} else {
			return '<span>'.$p.'</span> ';
		}
	}
	function createPagination($page, $count, $a) {
		global $blogurl, $urlbefore, $urlafter;
		$pagination = '';
		$count = ceil($count/10);
		if ($page < 1) {
			header('Location: '.$urlbefore.$blogurl.$a.'1'.$urlafter);
		} elseif ($page > $count) {
			header('Location: '.$urlbefore.$blogurl.$a.$count.$urlafter);
		}
		if ($page > 1) {
			$p = $page-1;
			$pagination .= '<a href="'.$urlbefore.$blogurl.$a.$p.$urlafter.'">« '.locale('link_back',true).'</a> ';
		} else {
			$pagination .= '<span class="inactive">« '.locale('link_back',true).'</span> ';
		}
		if ($count <= 10) {
			for($i = 1; $i <= $count; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
		} elseif ($page < 5) {
			for($i = 1; $i <= $page+2; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
			$pagination .= '… ';
			$pagination .= getPaginationPage($count, $page, $a);
		} elseif ($page > $count - 5) {
			$pagination .= getPaginationPage(1, $page, $a);
			$pagination .= '… ';
			for($i = $page-1; $i <= $count; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
		} else {
			$pagination .= getPaginationPage(1, $page, $a);
			$pagination .= '… ';
			for($i = $page-1; $i <= $page+2; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
			$pagination .= '… ';
			$pagination .= getPaginationPage($count, $page, $a);
		}
		if ($page < $count) {
			$p = $page+1;
			$pagination .= '<a href="'.$urlbefore.$blogurl.$a.$p.$urlafter.'">'.locale('link_next',true).' »</a> ';
		} else {
			$pagination .= '<span class="inactive">'.locale('link_next',true).' »</span> ';
		}
		return $pagination;
	}

	if ($action == '' or $action == 'pages') {
		/* Start display blog overview */
		if ($argument == '') {
			$page = 1;
		} else {
			$page = intval($argument);
		}
		$articles = array();
		if ($handle = opendir('./data/blog/articles')) {
			while (false !== ($file = readdir($handle))) {
				if ($file != '.' && $file != '..') {
					$articles[] = $file;
				}
			}
			closedir($handle);
		}
		if (count($articles) != 0) {
			$start = $page*10-10;
			$end = $start+10;
			if (!array_key_exists($end, $articles)) {
				$end = count($articles);
			}
			$pagination = createPagination($page, count($articles), '/pages/');
			$blog.= '<p class="blogpaginationtop">'.$pagination.'</p>';
			natsort($articles);
			$articles = array_reverse($articles);
			for($i = $start; $i < $end; $i++) {
				displayArticle($articles[$i]);
			}
			$blog.= '<p class="blogpaginationbottom">'.$pagination.'</p>';
		} else {
			$blog.= '<p>ERROR: No articles found.</p>';
		}
		/* End display blog overview */
	} elseif ($action == 'articles') {
		/* Start display article */
		displayArticle($argument, false);
		$blog.= '<div id="comments">';
		$gb_data_file = './data/blog/articles/'.$argument.'/comments';
		$gb_output_reverse = false;
		ob_start();
		include('gb.php');
		$blog.= ob_get_contents();
		ob_end_clean();
		$blog.= '</div>';
		/* End display article */
	} elseif ($action == 'tags') {
		/* Start display tag overview */
		if ($query_string_data[2] == '') {
			$page = 1;
		} else {
			$page = intval($query_string_data[2]);
		}
		if (is_file('./data/blog/tags/'.$argument)) {
			$template->addToHead('<link rel="alternate" type="application/atom+xml" title="'.sprintf(locale('desc_feed-tag',true),$argument).'" href="'.$urlabsolute.'/blogfeed.php?l='.$locale_default.'&amp;p='.$query_string[0].'&amp;t='.urlencode($argument).'" />');
			$articles = file_get_contents('./data/blog/tags/'.$argument);
			$articles = explode("\n", $articles);
			$articles = array_reverse($articles);
			$pagination = createPagination($page, count($articles), '/tags/'.$argument.'/');
			$blog.= '<p class="blogpaginationtop">'.$pagination.'</p>';
			$start = $page*10-10;
			$end = $start+10;
			if (!array_key_exists($end, $articles)) {
				$end = count($articles);
			}
			for($i = $start; $i < $end; $i++) {
				displayArticle($articles[$i]);
			}
			$blog.= '<p class="blogpaginationbottom">'.$pagination.'</p>';
		} else {
			$blog.= '<p>ERROR: Tag doesn\'t exist.</p>';
		}
		/* End display tag overview */
	} else {
		$blog.= '<p>ERROR: Unknown action!</p>';
	}
} else {
	$blog = '<p>ERROR: Safety restriction in effect.</p>';
}

unset($locale);
?>

==> cms-db_v0.7.8.tar.gz: blog.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

chdir('./admin');
$locale = new LocalizingClass('blog', $locale_default);
chdir('../');

/* Prevent displaying files outside of the blog directory */
if (strpos($query_string_data, '..') === false) {
	$template->addToHead('<link rel="alternate" type="application/atom+xml" title="'.locale('desc_feed-common',true).'" href="'.$urlabsolute.'/blogfeed.php?l='.$locale_default.'&amp;p='.$query_string[0].'" />');

	$query_string_data = explode('/', $query_string_data);

	$action = $query_string_data[0];
	$argument = $query_string_data[1];

	$blogurl = $current_page;
	$blog = '';


	/*
	 * The following part handles the different blog attributes
	 */
	
	if (in_array('useh1', $blogattr)) {
		$opentitletag = '<h1 class="blogtitle">';
		$closetitletag = '</h1>';
	} elseif (in_array('useh2', $blogattr)) {
		$opentitletag = '<h2 class="blogtitle">';
		$closetitletag = '</h2>';
	} elseif (in_array('useh3', $blogattr)) {
		$opentitletag = '<h3 class="blogtitle">';
		$closetitletag = '</h3>';
	} elseif (in_array('useh4', $blogattr)) {
		$opentitletag = '<h4 class="blogtitle">';
		$closetitletag = '</h4>';
	} elseif (in_array('useh5', $blogattr)) {
		$opentitletag = '<h5 class="blogtitle">';
		$closetitletag = '</h5>';
	} elseif (in_array('useh6', $blogattr)) {
		$opentitletag = '<h6 class="blogtitle">';
		$closetitletag = '</h6>';
	} else {
		$opentitletag = '<div class="blogtitle">';
		$closetitletag = '</div>';
	}

	if (in_array('nocomments', $blogattr)) {
		$blogattr_comments = false;
	} else {
		$blogattr_comments = true;
	}

	if (in_array('nolinks', $blogattr)) {
		$blogattr_links = false;
	} else {
		$blogattr_links = true;
	}

	function displayArticle($article, $link = true) {
		global $blogurl, $urlbefore, $urlafter, $blog, $blogattr, $opentitletag, $closetitletag;
		if (file_exists('./data/blog/articles/'.$article.'/content')) {
			$blog .= '<div class="blogarticle">';
			$data = file_get_contents('./data/blog/articles/'.$article.'/content');
			$data = explode("\n", $data, 5);
			$title = $data[0];
			$data[1] = explode('-', $data[1], 2);
			$user = $data[1][0];
			$author = $data[1][1];
			if (file_exists('./data/users/'.$user)) {
				include('./data/users/'.$user);
				$author = $user;
			}
			$time = $data[2];
			$tags = $data[3];
			$text = $data[4];
			$blog.= '<div class="blogheader">';
			if ($blogattr_links && $link) {
				$blog.= $opentitletag.'<a href="'.$urlbefore.$blogurl.'/articles/'.$article.$urlafter.'">'.htmlspecialchars($title).'</a>'.$closetitletag;
			} else {
				$blog.= $opentitletag.htmlspecialchars($title).$closetitletag;
			}
			$blog.= '<div class="blogmeta">'.sprintf(locale('desc_meta',true), $author, date('d.m.Y', $time), date('H:i:s', $time)).'</div>';
			$blog.= '</div>';
			$blog.= '<div class="blogcontent">'.$text.'</div>';
			$tags = explode(' ', $tags);
			$blog.= '<div class="blogfooter">'.locale('desc_tags',true).' ';
			foreach ($tags as $tag) {
				$blog.= '<a href="'.$urlbefore.$blogurl.'/tags/'.$tag.$urlafter.'">'.$tag.'</a> ';
			}
			if ($blogattr_comments && $link) {
				if (file_exists('./data/blog/articles/'.$article.'/comments')) {
					$count = count(file('./data/blog/articles/'.$article.'/comments'));
					if ($count == 0) {
						$linktext = locale('link_no-comments',true);
					} elseif ($count == 1) {
						$linktext = locale('link_one-comment',true);
					} else {
						$linktext = $count.' '.locale('link_comments',true);
					}
				} else {
					$linktext = locale('link_no-comments',true);
				}
				$blog.= '- <a href="'.$urlbefore.$blogurl.'/articles/'.$article.$urlafter.'">'.$linktext.'</a></div>';
			} else {
				$blog.= '</div>';
			}
			$blog .= '</div>';
		} else {
			$blog.= '<p>ERROR: The article doesn\'t exist.</p>';
		}
	}
	function getPaginationPage($p, $page, $a) {
		global $blogurl, $urlbefore, $urlafter;
		if ($page != $p) {
			return '<a href="'.$urlbefore.$blogurl.$a.$p.$urlafter.'">'.$p.'</a> ';
		} else {
			return '<span>'.$p.'</span> ';
		}
	}
	function createPagination($page, $count, $a) {
		global $blogurl, $urlbefore, $urlafter;
		$pagination = '';
		$count = ceil($count/10);
		if ($page < 1) {
			header('Location: '.$urlbefore.$blogurl.$a.'1'.$urlafter);
		} elseif ($page > $count) {
			header('Location: '.$urlbefore.$blogurl.$a.$count.$urlafter);
		}
		if ($page > 1) {
			$p = $page-1;
			$pagination .= '<a href="'.$urlbefore.$blogurl.$a.$p.$urlafter.'">« '.locale('link_back',true).'</a> ';
		} else {
			$pagination .= '<span class="inactive">« '.locale('link_back',true).'</span> ';
		}
		if ($count <= 10) {
			for($i = 1; $i <= $count; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
		} elseif ($page < 5) {
			for($i = 1; $i <= $page+2; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
			$pagination .= '… ';
			$pagination .= getPaginationPage($count, $page, $a);
		} elseif ($page > $count - 5) {
			$pagination .= getPaginationPage(1, $page, $a);
			$pagination .= '… ';
			for($i = $page-1; $i <= $count; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
		} else {
			$pagination .= getPaginationPage(1, $page, $a);
			$pagination .= '… ';
			for($i = $page-1; $i <= $page+2; $i++) {
				$pagination .= getPaginationPage($i, $page, $a);
			}
			$pagination .= '… ';
			$pagination .= getPaginationPage($count, $page, $a);
		}
		if ($page < $count) {
			$p = $page+1;
			$pagination .= '<a href="'.$urlbefore.$blogurl.$a.$p.$urlafter.'">'.locale('link_next',true).' »</a> ';
		} else {
			$pagination .= '<span class="inactive">'.locale('link_next',true).' »</span> ';
		}
		return $pagination;
	}

	if ($action == '' or $action == 'pages') {
		/* Start display blog overview */
		if ($argument == '') {
			$page = 1;
		} else {
			$page = intval($argument);
		}
		$articles = array();
		if ($handle = opendir('./data/blog/articles')) {
			while (false !== ($file = readdir($handle))) {
				if ($file != '.' && $file != '..') {
					$articles[] = $file;
				}
			}
			closedir($handle);
		}
		if (count($articles) != 0) {
			$start = $page*10-10;
			$end = $start+10;
			if (!array_key_exists($end, $articles)) {
				$end = count($articles);
			}
			$pagination = createPagination($page, count($articles), '/pages/');
			$blog.= '<p class="blogpaginationtop">'.$pagination.'</p>';
			natsort($articles);
			$articles = array_reverse($articles);
			for($i = $start; $i < $end; $i++) {
				displayArticle($articles[$i]);
			}
			$blog.= '<p class="blogpaginationbottom">'.$pagination.'</p>';
		} else {
			$blog.= '<p>ERROR: No articles found.</p>';
		}
		/* End display blog overview */
	} elseif ($action == 'articles') {
		/* Start display article */
		displayArticle($argument, false);
		if ($blogattr_comments) {
			$blog.= '<div id="comments">';
			$gb_data_file = './data/blog/articles/'.$argument.'/comments';
			$gb_output_reverse = false;
			ob_start();
			include('gb.php');
			$blog.= ob_get_contents();
			ob_end_clean();
			$blog.= '</div>';
		}
		/* End display article */
	} elseif ($action == 'tags') {
		/* Start display tag overview */
		if ($query_string_data[2] == '') {
			$page = 1;
		} else {
			$page = intval($query_string_data[2]);
		}
		if (is_file('./data/blog/tags/'.$argument)) {
			$template->addToHead('<link rel="alternate" type="application/atom+xml" title="'.sprintf(locale('desc_feed-tag',true),$argument).'" href="'.$urlabsolute.'/blogfeed.php?l='.$locale_default.'&amp;p='.$query_string[0].'&amp;t='.urlencode($argument).'" />');
			$articles = file_get_contents('./data/blog/tags/'.$argument);
			$articles = explode("\n", $articles);
			$articles = array_reverse($articles);
			$pagination = createPagination($page, count($articles), '/tags/'.$argument.'/');
			$blog.= '<p class="blogpaginationtop">'.$pagination.'</p>';
			$start = $page*10-10;
			$end = $start+10;
			if (!array_key_exists($end, $articles)) {
				$end = count($articles);
			}
			for($i = $start; $i < $end; $i++) {
				displayArticle($articles[$i]);
			}
			$blog.= '<p class="blogpaginationbottom">'.$pagination.'</p>';
		} else {
			$blog.= '<p>ERROR: Tag doesn\'t exist.</p>';
		}
		/* End display tag overview */
	} else {
		$blog.= '<p>ERROR: Unknown action!</p>';
	}
} else {
	$blog = '<p>ERROR: Safety restriction in effect.</p>';
}

unset($locale);
?>
